==> haskell-tasty-hedgehog-0.1.0.2-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-hedgehog
version: 0.1.0.2
id: tasty-hedgehog-0.1.0.2-2ltUaIXaTyF3Qv4J8d1hoD
key: tasty-hedgehog-0.1.0.2-2ltUaIXaTyF3Qv4J8d1hoD
license: BSD3
copyright: Copyright (c) 2017, Commonwealth Scientific and Industrial Research Organisation (CSIRO) ABN 41 687 119 230.
maintainer: dave.laing.80@gmail.com
homepage: https://github.com/qfpl/tasty-hedghog
synopsis: Integrates the hedgehog testing library with the tasty testing framework.
description:
    Integrates the hedgehog testing library with the tasty testing framework.
category: Testing
author: Dave Laing
exposed: True
indefinite: False
exposed-modules:
    Test.Tasty.Hedgehog
abi: 6c8a1b28fb1ae15e84bcd0028af389b4
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/tasty-hedgehog-0.1.0.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/tasty-hedgehog-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/tasty-hedgehog-0.1.0.2
hs-libraries: HStasty-hedgehog-0.1.0.2-2ltUaIXaTyF3Qv4J8d1hoD
depends:
    base-4.10.1.0 tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2
    tasty-1.0.1-AWWNaFTEpDABJ6I60QHIFP
    hedgehog-0.5.2-H3GPgIKayzc8kxrF4wza1j
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2=b5d07becd47ba21e20b584b61ad0f06d
             tasty-1.0.1-AWWNaFTEpDABJ6I60QHIFP=676bfe39e5968a7e880bebc46f35c0bf
             hedgehog-0.5.2-H3GPgIKayzc8kxrF4wza1j=679f5cec96fda72cc9f02d87295dabe9
haddock-interfaces: /usr/share/doc/haskell-tasty-hedgehog/html/tasty-hedgehog.haddock
haddock-html: /usr/share/doc/haskell-tasty-hedgehog/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-hedgehog-0.1.0.2-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-hedgehog
version: 0.1.0.2
id: tasty-hedgehog-0.1.0.2-GMsT2vbVE4a3NMdHd23Hxk
key: tasty-hedgehog-0.1.0.2-GMsT2vbVE4a3NMdHd23Hxk
license: BSD3
copyright: Copyright (c) 2017, Commonwealth Scientific and Industrial Research Organisation (CSIRO) ABN 41 687 119 230.
maintainer: dave.laing.80@gmail.com
homepage: https://github.com/qfpl/tasty-hedghog
synopsis: Integrates the hedgehog testing library with the tasty testing framework.
description:
    Integrates the hedgehog testing library with the tasty testing framework.
category: Testing
author: Dave Laing
exposed: True
indefinite: False
exposed-modules:
    Test.Tasty.Hedgehog
abi: c37b78ed99887e7c901b11908eed895b
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/tasty-hedgehog-0.1.0.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/tasty-hedgehog-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/tasty-hedgehog-0.1.0.2
hs-libraries: HStasty-hedgehog-0.1.0.2-GMsT2vbVE4a3NMdHd23Hxk
depends:
    base-4.10.1.0 tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2
    tasty-1.0.1-K2rsmdQu5cZEc4jR5Y73ik
    hedgehog-0.5.2-35DxGRR1NFSDlSoJE0lhSZ
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2=b5d07becd47ba21e20b584b61ad0f06d
             tasty-1.0.1-K2rsmdQu5cZEc4jR5Y73ik=ebb3680bb17064f549df9640b7cd1369
             hedgehog-0.5.2-35DxGRR1NFSDlSoJE0lhSZ=052dfcb4be81210a7febffdd4ad8e08a
haddock-interfaces: /usr/share/doc/haskell-tasty-hedgehog/html/tasty-hedgehog.haddock
haddock-html: /usr/share/doc/haskell-tasty-hedgehog/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
